# Minecraft Offline UUID Generator

This Python Program takes a Username and gives back a Minecraft Offline UUID

## Usage

```bash
#For Help 
mc-offline-uuid -h
```


## Building

To Build you can use a programm named 'just' or copy the needed instructions from the justfile

```bash
pip install build
```


# Source:
[Source](https://github.com/Faiataiga/mc-uuid-check)
